===============================
SNP Mutator
===============================


.. Image showing the PyPI version badge - links to PyPI
.. image:: https://img.shields.io/pypi/v/snp-mutator.svg
        :target: https://pypi.python.org/pypi/snp-mutator

.. Image showing the PyPi download per month count  - links to PyPI
.. image:: https://img.shields.io/pypi/dm/snp-mutator.svg
        :target: https://pypi.python.org/pypi/snp-mutator

.. Image showing the Travis Continuous Integration test status, commented out for now
.. .. image:: https://img.shields.io/travis/CFSAN-Biostatistics/snp-mutator.svg
..        :target: https://travis-ci.org/CFSAN-Biostatistics/snp-mutator



Generate mutated sequence files from a reference genome.

SNP Mutator was developed by the United States Food 
and Drug Administration, Center for Food Safety and Applied Nutrition.

* Free software
* Documentation: https://snp-mutator.readthedocs.org.
* Source Code: https://github.com/CFSAN-Biostatistics/snp-mutator
* PyPI Distribution: https://pypi.python.org/pypi/snp-mutator


Features
--------

* Reads a fasta file and generates any number of mutated fasta replicate files.
* Mutations can be any number of single-base substitutions, insertions, and deletions at randomly 
  chosen positions, uniformly distributed across the genome.
* Generates a summary file listing the original base and the mutation for all mutated positions.


Citing SNP Mutator
--------------------------------------

To cite SNP Mutator, please reference the SNP Mutator GitHub repository:

    https://github.com/CFSAN-Biostatistics/snp-mutator


License
-------

See the LICENSE file included in the SNP Mutator distribution.
